// Copyright (C) 1996 by Wolfgang Platzer
// email: wplatzer@iaik.tu-graz.ac.at
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//

/**
 * This class shows some examples for using the cryptiX library.
 */

package cryptiX.apps;

import java.io.*;
import java.util.*;

import cryptiX.utils.*;
import cryptiX.rsa.*;
import cryptiX.user.*;
import cryptiX.crypto.Md5Hash;
import cryptiX.asn1.*;

class TestKeyGenSpeed {

    public static void main(String args[]) throws IOException {

        DataInputStream dis = new DataInputStream(System.in);
        String line;
        long start;
        long end;
        int count = 50;
        int bits = 512;

        try {
            if (args.length >= 1)
                bits = new Integer(args[0]).intValue();

            if (args.length >= 2)
                count = new Integer(args[1]).intValue();
        } catch (NumberFormatException ex) {
            System.out.println("usage: TestKeyGenSpeed [keylength in bits] [number of tests]");
            System.out.println("default values: TestKeyGenSpeed 512 50");
            System.exit(1);
        }

        double time = 0.0;
        RSAPrivateKey sk = new RSAPrivateKey();

        for (int i=0; i<count; i++) {
            start = System.currentTimeMillis();
            sk.generateKeys(bits);
            end = System.currentTimeMillis();

            time += (double)(end-start) / 1000;
            System.out.println(i+": "+(double)(end-start) / 1000);
        }

        System.out.println("\naverage time for generating a "+bits+" bit key: "+time/count);

        line = dis.readLine();
    }
}

