//
// OBJECTFactory.java --
//
// Author: Pekka Nikander <pnr@tequila.nixu.fi>
//
// Copyright 1996 by Nixu Oy, Helsinki, Finland
//
// Created: Sun Mar 24 17:59:34 1996
// Last modified: Thu Apr 11 09:36:15 1996 pnr
//

package cryptiX.asn1;

import cryptiX.utils.Factory;
import cryptiX.asn1.ASN1Object;

/**
 * OBJECT factory.  The only reason for this is to behave with
 * Java package protection, see the Factory class for further
 * explanation.
 */

final
class OBJECTFactory extends Factory {
  protected OBJECTFactory() {
    super();
  }
  /**
   * Performs the actual object creation.
   * Needed to be implemented as a non-static function in the
   * subclasses of Factory, in order to behave with Java
   * package protection mechanisms.
   * @param implementation a concreate class, local to this package
   * @exception InstantiationException if the implementation class
   *		was not available, or if it happens to be an abstract
   *		class or an interface.
   * @exception IllegalAccessException if an attempt was made to
   *		instantiate a of a foreign package not supporting
   *		foreign instantiation.
   */
  protected Object create(Class implementation)
    throws InstantiationException, IllegalAccessException {
    return implementation.newInstance();
  }

  protected Object create(Class iface, Object type, boolean singleton)
    throws InstantiationException {
    return super.create(iface, type, singleton);
  }
  protected void register(Class iface, Object type, Class implementation) {
    super.register(iface, type, implementation);
  }
}
