// Copyright (C) 1996 by Wolfgang Platzer
// email: wplatzer@iaik.tu-graz.ac.at
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//

package cryptiX.user;

import java.io.*;
import cryptiX.asn1.*;
import cryptiX.utils.Util;


/**
 * This class is used to deal with x509v3 extensions
 */


class Extension {

    String extensionID = null;
    boolean critical = false;
    ASN1 value = null;


    public Extension(ASN1Object extObj) throws CodingException {

        String str;
        ASN1 ext = new ASN1(extObj);

        extensionID = (String)ext.getComponentAt(0).getValue();

        int count = ext.components();
        if (count == 3)
//            critical = new Boolean((Boolean)ext.getComponentAt(1).getValue()).booleanValue();
            critical = ((Boolean)ext.getComponentAt(1).getValue()).booleanValue();

        value = new ASN1((byte[])ext.getComponentAt(count-1).getValue());

/*        try {
        File file = new File("D:\\ssl\\certs\\obj.der");
        FileOutputStream os = new FileOutputStream(file);

        os.write(value);
        os.close();
        } catch (IOException ex) {
        }
*/
        if (critical)
            System.out.println("Extension "+extensionID+" is critical:");
        else
            System.out.println("Extension "+extensionID+" is not critical:");

        System.out.println(value);
    }
}


class Extensions {



    /**
     * constructor for ASN1Object: SEQUENCE OF Extension
     */
    public Extensions(ASN1Object extObj) {

        ASN1Object set;

        if (!extObj.isA(ASN.SEQUENCE))            // this works only for a sequence
            return; // @todo throw exception

        for (int i=0; i<extObj.countComponents(); i++) {
            try {
                new Extension((ASN1Object)extObj.getComponent(i));
            } catch (CodingException ex) {
                System.out.println("Extension coding exception!");
            }
        }
    }
}

