//
// Composite.java --
//
// Author: Pekka Nikander <pnr@tequila.nixu.fi>
//
// Copyright 1996 by Nixu Oy, Helsinki, Finland
//
// Created: Tue Mar 19 14:03:14 1996
// Last modified: Sun Mar 31 23:35:11 1996 pnr
//

package cryptiX.utils;

/**
 * This interface defines the common operations for all objects
 * following the Composite pattern [Gamma, p. 164].
 */

public interface Composite {
  /**
   * Add a new component to the container object.  If the
   * object accessed is not a container object, throws
   * NonCompositeException.
   */
  public void addComponent(Composite component);

  /**
   * Add a new component to the container object at a given location.
   * If the object accessed is not a container object, throws
   * NonCompositeException.
   */
  public void addComponent(Composite component, int index);

  /**
   * Removes a component from the container.  If the object
   * accessed is not a container, throws NonCompositeException.
   * If the component is not in the container, does nothing.
   */
  public void removeComponent(Composite component);

  /**
   * Removes a component at the given location within the container.
   * If the object accessed is not a container, throws NonCompositeException.
   * If the index refers outside bounds, IndexOutOfBounds is thrown.
   */
  public void removeComponent(int index);

  /**
   * Returns the component at the given location within a sequence.
   * If the object accessed is not a container, throws NonCompositeException.
   * If the index refers outside bounds, IndexOutOfBounds is thrown.
   */
  public Composite getComponent(int index);

  /**
   * Sets the component at the given location within a sequence.
   * If the object accessed is not a container, throws NonCompositeException.
   * If the index refers outside bounds, IndexOutOfBounds is thrown.
   */
  public void setComponent(int index, Composite value);

  /**
   * Returns the number of component objects.  Zero if none.
   */
  public int countComponents();

  /**
   * Returns an Enumeration that iterates over the component objects.
   * Returns a NullEnumeration if this not a container.
   */
  public java.util.Enumeration getComponents();
}
